==> haskell-profunctors-5.4-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.4
id: profunctors-5.4-3h6ix2rxY1UvIjMIvDbb3
key: profunctors-5.4-3h6ix2rxY1UvIjMIvDbb3
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors.
category: Control, Categories
abi: 27152c90a7508f371304e6ece4d20a26
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
import-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/profunctors-5.4
hs-libraries: HSprofunctors-5.4-3h6ix2rxY1UvIjMIvDbb3
depends:
    base-4.12.0.0 base-orphans-0.8.1-ADx13UE5kNMLP8OA0gQSRH
    bifunctors-5.5.5-H6ZQWPR6nusfP0g8Bh48f
    comonad-5.0.5-JWUmcozaCSQ5DKxgYDY491
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-FcQ97OMqC5EFkQIWzW6oEc
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.5-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.5
id: profunctors-5.5-C3RSa0newLDGrqKqFpjE7c
key: profunctors-5.5-C3RSa0newLDGrqKqFpjE7c
license: BSD-3-Clause
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors.
category: Control, Categories
abi: 978f31c5fbda219524489d9b250b32a7
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
import-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/profunctors-5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/profunctors-5.5
hs-libraries: HSprofunctors-5.5-C3RSa0newLDGrqKqFpjE7c
depends:
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    bifunctors-5.5.5-AT2O4t2mUeVLY6LKXIjARE
    comonad-5.0.5-CthxCPGmo5h60L0drN1HHd
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    distributive-0.6-H2z9MTlb1YgoCr4okC28M
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
